.. eerste:


.. raw:: html

    <br>
    <center>

eerste
======

.. raw:: html

    </center>
    <br>

    Geachte leden van de Eerste Kamer de Staten Generaal,

Als u toch besluit de Wet verplichte GGZ aan te nemen, wens ik u dat liever te zien doen in het zekerheidbewustzijn dat het hier gif betreft en niet het beloofde "kan geen schade" medicijn.

Er is bewijs dat antipsychotica gif zijn:

| haloperiodol (haldol) - https://echa.europa.eu/substance-information/-/substanceinfo/100.000.142
| clozapine (leponex) - https://echa.europa.eu/substance-information/-/substanceinfo/100.024.831
| olanzapine (zyprexa) - https://echa.europa.eu/substance-information/-/substanceinfo/100.125.320
| aripriprazole (abilify) https://echa.europa.eu/substance-information/-/substanceinfo/100.112.532

Dat u deze wet moet heroverwegen, dat het hier gif betreft en niet uw vernoemde medicatie.

Hoogachtend,



Bart Thate
Heerhugowaard
21-10-2017
